@@ -1,6 +1,6 @@
 from struct import unpack
 import socket
-from asyncio import shield
+from asyncio import shield, wait_for, wait
 import asyncio
 import math
 import errno
@@ -26,6 +26,8 @@ class BaseProtocol:
         station = kwargs.get('code')
         sock = kwargs.get('sock')
         self.timeout = kwargs.get('timeout', 1)
+        self.raise_timeout = kwargs.get('raise_timeout', 1)
+        self.raise_incompleteread = kwargs.get("raise_incomplete_read",False)        
         self.host = kwargs.get('host')
         self.port = kwargs.get('port')
         self.sock = self.create_socket(None)
@@ -91,7 +93,10 @@ class BaseProtocol:
                     self.logger.error(info)
             except asyncio.TimeoutError as te:
                 self.logger.exception("Tiempo fuera en intento de conexión %s" %te)
-                continue
+                if self.raise_timeout:
+                    raise te
+                else:
+                    continue
             except socket.timeout as timeout:
                 self.on_blocking()
                 self.logger.error(
@@ -200,11 +205,18 @@ class BaseProtocol:
     async def readbytes(self, reader, n):
         future = reader.readexactly(n)
         try:
-            result = await asyncio.wait_for(future, timeout=self.timeout)
+            result = await wait_for(future, timeout=self.timeout)
             return result
         except asyncio.TimeoutError as te:
-            self.logger.exception("Tiempo fuera al leer en readbytes, %s"%te)
-            raise te
+            print("Error Timeout al leer %d bytes en %s" %(n, self.station))
+            self.logger.exception("Station %s, Tiempo fuera al leer en readbytes, %s"%(self.station,te))
+            if self.raise_timeout:
+                raise te
+        except asyncio.IncompleteReadError as ir:
+            print("Incomplete read, station %s" %self.station, reader, n)
+            self.logger.exception("Station %s, Tiempo fuera al no poder leer en readbytes %s bytes, %s"%(n, self.station,ir))
+            raise ir
+            
 
     async def get_message_header(self, idc):
         self.idc = idc
